@@ -12,7 +12,8 @@ jags <- function( data, inits,
                   progress.bar = "text",
                   digits = 5,
                   RNGname = c("Wichmann-Hill", "Marsaglia-Multicarry", "Super-Duper", "Mersenne-Twister"),
-                  jags.module = c("glm","dic")
+                  jags.module = c("glm","dic"),
+                  quiet = FALSE
                   )
 {
   #require( rjags )
@@ -92,10 +93,10 @@ jags <- function( data, inits,
 
 
   #load.module("lecuyer")
-  if(!is.null(jags.module)){
+  if(length(jags.module) > 0L) {
     n.module <- length(jags.module)
-    for(m in 1:n.module){
-        load.module(jags.module[m])
+    for(m in seq_len(n.module)) {
+        load.module(jags.module[m], quiet = quiet)
     }
   }
 
@@ -152,7 +153,8 @@ jags <- function( data, inits,
                   data     = data,
                   inits    = init.values,
                   n.chains = n.chains,
-                  n.adapt  = 0 )
+                  n.adapt  = 0,
+                  quiet = quiet )
   #}
   adapt( m,
          n.iter         = n.adapt,
